@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.034';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.035';
 }
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
@@ -133,17 +133,32 @@ sub release_plugins {
             TestRelease
             CheckChangesHasContent
             CheckPrereqsIndexed
-            ConfirmRelease
         },
+        [
+            'Git::Check' => {
+                allow_dirty => [ qw{ cpanfile .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
+            },
+        ],
+        'ConfirmRelease',
     );
 
-    push @plugins, 'UploadToCPAN'
-        unless $self->is_private;
+    push @plugins, [ 'Git::Commit' => {
+        allow_dirty => [ qw{ cpanfile .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
+    }];
+    push @plugins, [ 'Git::Tag' => {
+        tag_format  => '%v',
+        signed      => $self->sign, # 1,
+    }];
     push @plugins, [ 'Git::CommitBuild' => {
         release_branch       => 'release/cpan',
         release_message      => 'Full build of CPAN release %v%t',
         multiple_inheritance => 1,
     }];
+    push @plugins, 'UploadToCPAN'
+        unless $self->is_private;
+    push @plugins, [ 'Git::Push' => {
+        push_to => [ 'origin', 'origin refs/heads/release/cpan:refs/heads/release/cpan' ],
+    }];
     push @plugins, [ Signature => { sign => 'always' } ]
         if $self->sign;
     push @plugins, [ Twitter => { hash_tags => '#perl #cpan' } ]
@@ -212,17 +227,9 @@ sub configure {
         : [ PodWeaver => { config_plugin => '@RSRCHBOY' } ]
         ;
 
-    $self->add_plugins([ NextRelease => {
-        format => '%-8V  %{yyyy-MM-dd HH:mm:ss ZZZZ}d',
-    }]);
-
-    $self->add_bundle(Git => {
-        allow_dirty => [ qw{ cpanfile .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
-        tag_format  => '%v',
-        signed      => $self->sign, # 1,
-        # also push to our fully-built branch
-        push_to     => [ 'origin', 'origin refs/heads/release/cpan:refs/heads/release/cpan' ],
-    });
+    $self->add_plugins(
+        [ NextRelease => { format => '%-8V  %{yyyy-MM-dd HH:mm:ss ZZZZ}d' }],
+    );
 
     $self->add_plugins([ 'Git::NextVersion' =>
         #;first_version = 0.001       ; this is the default
@@ -309,7 +316,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.034 of Dist::Zilla::PluginBundle::RSRCHBOY - released February 23, 2013 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.035 of Dist::Zilla::PluginBundle::RSRCHBOY - released February 23, 2013 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
